@@ -37,14 +37,9 @@
 #include "Globals.h"
 #include "GmicStdlib.h"
 #include "ImageTools.h"
-#include "LayersExtentProxy.h"
-#include "Logger.h"
 #include "Misc.h"
 #include "OverrideCursor.h"
 #include "Settings.h"
-#ifndef gmic_core
-#include "CImg.h"
-#endif
 #include "gmic.h"
 
 namespace GmicQt
@@ -55,9 +50,9 @@ const PreviewWidget::PreviewRect PreviewWidget::PreviewRect::Full{0.0, 0.0, 1.0,
 PreviewWidget::PreviewWidget(QWidget * parent) : QWidget(parent)
 {
   setAutoFillBackground(false);
-  _image = new cimg_library::CImg<float>;
+  _image = new gmic_library::gmic_image<float>;
   _image->assign();
-  _savedPreview = new cimg_library::CImg<float>;
+  _savedPreview = new gmic_library::gmic_image<float>;
   _savedPreview->assign();
   _transparency.load(":resources/transparency.png");
 
@@ -85,12 +80,12 @@ PreviewWidget::~PreviewWidget()
   delete _savedPreview;
 }
 
-const cimg_library::CImg<float> & PreviewWidget::image() const
+const gmic_library::gmic_image<float> & PreviewWidget::image() const
 {
   return *_image;
 }
 
-void PreviewWidget::setPreviewImage(const cimg_library::CImg<float> & image)
+void PreviewWidget::setPreviewImage(const gmic_library::gmic_image<float> & image)
 {
   _errorMessage.clear();
   _errorImage = QImage();
@@ -212,8 +207,8 @@ void PreviewWidget::updateOriginalImagePosition()
 
 void PreviewWidget::updateErrorImage()
 {
-  cimg_library::CImgList<float> images;
-  cimg_library::CImgList<char> imageNames;
+  gmic_library::gmic_list<float> images;
+  gmic_library::gmic_list<char> imageNames;
   images.assign();
   imageNames.assign();
   gmic_image<float> image;
@@ -239,7 +234,7 @@ void PreviewWidget::updateErrorImage()
     return;
   }
   QImage qimage;
-  convertCImgToQImage(images.front(), qimage);
+  convertGmicImageToQImage(images.front(), qimage);
   if (qimage.size() != size()) {
     _errorImage = qimage.scaled(size());
   } else {
@@ -375,7 +370,7 @@ void PreviewWidget::paintPreview(QPainter & painter)
     painter.fillRect(_imagePosition, QBrush(_transparency));
   }
   QImage qimage;
-  convertCImgToQImage(_image->get_resize(_imagePosition.width(), _imagePosition.height(), 1, -100, 1), qimage);
+  convertGmicImageToQImage(_image->get_resize(_imagePosition.width(), _imagePosition.height(), 1, -100, 1), qimage);
   painter.drawImage(_imagePosition, qimage);
   paintKeypoints(painter);
 }
@@ -393,7 +388,7 @@ void PreviewWidget::paintOriginalImage(QPainter & painter)
       painter.fillRect(_imagePosition, QBrush(_transparency));
     }
     QImage qimage;
-    convertCImgToQImage(image, qimage);
+    convertGmicImageToQImage(image, qimage);
     painter.drawImage(_imagePosition, qimage);
     paintKeypoints(painter);
   }
@@ -463,7 +458,7 @@ double PreviewWidget::currentZoomFactor() const
 
 bool PreviewWidget::event(QEvent * event)
 {
-  if (event->type() == QEvent::WindowActivate && _pendingResize) {
+  if ((event->type() == QEvent::WindowActivate) && _pendingResize) {
     _pendingResize = false;
     if (width() && height()) {
       updateVisibleRect();
@@ -487,10 +482,9 @@ bool PreviewWidget::eventFilter(QObject *, QEvent * event)
   return false;
 }
 
-void PreviewWidget::leaveEvent(QEvent *)
-{
-  OverrideCursor::setWaiting(false);
-}
+void PreviewWidget::leaveEvent(QEvent *) {}
+
+void PreviewWidget::enterEvent(QEvent *) {}
 
 void PreviewWidget::wheelEvent(QWheelEvent * event)
 {
@@ -858,7 +852,7 @@ QSize PreviewWidget::originalImageCropSize()
   return CroppedActiveLayerProxy::getSize(_visibleRect.x, _visibleRect.y, _visibleRect.w, _visibleRect.h);
 }
 
-void PreviewWidget::getOriginalImageCrop(cimg_library::CImg<float> & image)
+void PreviewWidget::getOriginalImageCrop(gmic_library::gmic_image<float> & image)
 {
   CroppedActiveLayerProxy::get(image, _visibleRect.x, _visibleRect.y, _visibleRect.w, _visibleRect.h);
 }
